# TODO

- [ ] Configure UV project correctly
- [ ] Rebrand Package as harwest2 and upload to PyPi
- [ ] Add tests
- [ ] Debug harvesting
- [ ] General debug
- [ ] Add CI/CD for testing and uploading to PyPi
- [ ] Recognize Directory as either relative or absolute (with ~ for home)
- [ ] Separate the subject of commits from body
- [ ] Add linting with ruff and mypy
- [ ] Improve CLI interface
